<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Travel Life Pro
 * @since Travel Life Pro 1.0.0
 */

if ( ! function_exists( 'travel_life_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Travel Life Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function travel_life_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'travel_life_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'travel_life_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Travel Life Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function travel_life_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'travel_life_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'travel_life_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Travel Life Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function travel_life_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'travel_life_pro_theme_options[pagination_enable]' )->value();
	}
endif;

if ( ! function_exists( 'travel_life_pro_is_static_homepage_enable' ) ) :
	/**
	 * Check if static homepage is enabled.
	 *
	 * @since Travel Life Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function travel_life_pro_is_static_homepage_enable( $control ) {
		return ( 'page' == $control->manager->get_setting( 'show_on_front' )->value() );
	}
endif;

/**
 * Check if topbar section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_topbar_contact_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[top_bar_contact_enable]' )->value() );
}
/**
 * Check if topbar section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_topbar_button_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[topbar_button_enable]' )->value() );
}
/**
 * Check if topbar section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_topbar_ads_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'travel_life_pro_theme_options[home_layout]' )->value();
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[top_advertisement_enable]' )->value() &&  in_array($home_layout,array('sixth-design')));
}

/**
 * Front Page Active Callbacks
 */

/**
 * Check if slider section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[slider_content_type]' )->value();
	return travel_life_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[slider_content_type]' )->value();
	return travel_life_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is post.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[slider_content_type]' )->value();
	return travel_life_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

function travel_life_pro_is_slider_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[slider_content_type]' )->value();
	return travel_life_pro_is_slider_section_enable( $control ) && ( 'trip' == $content_type );
}

function travel_life_pro_is_slider_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[slider_content_type]' )->value();
	return travel_life_pro_is_slider_section_enable( $control ) && ( 'trip-types' == $content_type );
}

function travel_life_pro_is_slider_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[slider_content_type]' )->value();
	return travel_life_pro_is_slider_section_enable( $control ) && ( 'activity' == $content_type );
}

function travel_life_pro_is_slider_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[slider_content_type]' )->value();
	return travel_life_pro_is_slider_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if featured section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_featured_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[featured_section_enable]' )->value() );
}

/**
 * Check if featured section content type is page.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_featured_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[featured_content_type]' )->value();
	return travel_life_pro_is_featured_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured section content type is post.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_featured_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[featured_content_type]' )->value();
	return travel_life_pro_is_featured_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if featured section content type is trip.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_featured_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[featured_content_type]' )->value();
	return travel_life_pro_is_featured_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if featured section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_featured_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[featured_content_type]' )->value();
	return travel_life_pro_is_featured_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if featured section content type is trip types.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_featured_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[featured_content_type]' )->value();
	return travel_life_pro_is_featured_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if featured section content type is destination.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_featured_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[featured_content_type]' )->value();
	return travel_life_pro_is_featured_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if featured section content type is activity.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_featured_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[featured_content_type]' )->value();
	return travel_life_pro_is_featured_section_enable( $control ) && ( 'activity' == $content_type );
}

/**
 * Check if popular destination section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_popular_destination_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[popular_destination_section_enable]' )->value() );
}

/**
 * Check if popular destination section content type is page.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_popular_destination_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[popular_destination_content_type]' )->value();
	return travel_life_pro_is_popular_destination_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular destination section content type is post.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_popular_destination_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[popular_destination_content_type]' )->value();
	return travel_life_pro_is_popular_destination_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular destination section content type is trip.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_popular_destination_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[popular_destination_content_type]' )->value();
	return travel_life_pro_is_popular_destination_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if popular destination section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_popular_destination_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[popular_destination_content_type]' )->value();
	return travel_life_pro_is_popular_destination_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular destination section content type is trip types.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_popular_destination_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[popular_destination_content_type]' )->value();
	return travel_life_pro_is_popular_destination_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if popular destination section content type is destination.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_popular_destination_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[popular_destination_content_type]' )->value();
	return travel_life_pro_is_popular_destination_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if popular destination section content type is activity.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_popular_destination_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[popular_destination_content_type]' )->value();
	return travel_life_pro_is_popular_destination_section_enable( $control ) && ( 'activity' == $content_type );
}

/**
 * Check if about section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if about section content type is post.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[about_content_type]' )->value();
	return travel_life_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section content type is page.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[about_content_type]' )->value();
	return travel_life_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if about section content type is custom.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_about_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[about_content_type]' )->value();
	return travel_life_pro_is_about_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if about section wp travel is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_about_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[about_content_type]' )->value();
	return travel_life_pro_is_about_section_enable( $control ) && class_exists( 'WP_Travel' );
}



/**
 * Check if project section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_project_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[project_section_enable]' )->value() );
}


/**
 * Check if package section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_package_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[package_section_enable]' )->value() );
}

/**
 * Check if package section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_package_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[package_content_type]' )->value();
	return travel_life_pro_is_package_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if package section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_package_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[package_content_type]' )->value();
	return travel_life_pro_is_package_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if package section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_package_section_content_cat_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[package_content_type]' )->value();
	return travel_life_pro_is_package_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if package section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_package_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[package_content_type]' )->value();
	return travel_life_pro_is_package_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if package section content type is trip types.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_package_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[package_content_type]' )->value();
	return travel_life_pro_is_package_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if package section content type is destination.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_package_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[package_content_type]' )->value();
	return travel_life_pro_is_package_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if package section content type is activity.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_package_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[package_content_type]' )->value();
	return travel_life_pro_is_package_section_enable( $control ) && ( 'activity' == $content_type );
}

/**
 * Check if traveler choice section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_traveler_choice_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[traveler_choice_section_enable]' )->value() );
}

/**
 * Check if traveler choice section content type is page.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_traveler_choice_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[traveler_choice_content_type]' )->value();
	return travel_life_pro_is_traveler_choice_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if traveler choice section content type is post.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_traveler_choice_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[traveler_choice_content_type]' )->value();
	return travel_life_pro_is_traveler_choice_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if traveler choice section content type is trip.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_traveler_choice_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[traveler_choice_content_type]' )->value();
	return travel_life_pro_is_traveler_choice_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if traveler choice section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_traveler_choice_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[traveler_choice_content_type]' )->value();
	return travel_life_pro_is_traveler_choice_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if traveler choice section content type is trip types.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_traveler_choice_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[traveler_choice_content_type]' )->value();
	return travel_life_pro_is_traveler_choice_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if traveler choice section content type is destination.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_traveler_choice_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[traveler_choice_content_type]' )->value();
	return travel_life_pro_is_traveler_choice_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if traveler choice section content type is activity.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_traveler_choice_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[traveler_choice_content_type]' )->value();
	return travel_life_pro_is_traveler_choice_section_enable( $control ) && ( 'activity' == $content_type );
}

/**
 * Check if service section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[service_section_enable]' )->value() );
}


function travel_life_pro_is_service_section_icon_enable( $control ) {
	$icon = $control->manager->get_setting( 'travel_life_pro_theme_options[service_section_icon_enable]' )->value();
	return travel_life_pro_is_service_section_enable( $control ) && ( true == $icon );
}
/**
 * Check if service section content type is post.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[service_content_type]' )->value();
	return travel_life_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section seperator.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_service_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[service_content_type]' )->value();
	return travel_life_pro_is_service_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if service section content type is page.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[service_content_type]' )->value();
	return travel_life_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if service section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[service_content_type]' )->value();
	return travel_life_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}

function travel_life_pro_is_service_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[service_content_type]' )->value();
	return travel_life_pro_is_service_section_enable( $control ) && ( 'trip' == $content_type );
}

function travel_life_pro_is_service_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[service_content_type]' )->value();
	return travel_life_pro_is_service_section_enable( $control ) && ( 'trip-types' == $content_type );
}

function travel_life_pro_is_service_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[service_content_type]' )->value();
	return travel_life_pro_is_service_section_enable( $control ) && ( 'activity' == $content_type );
}

function travel_life_pro_is_service_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[service_content_type]' )->value();
	return travel_life_pro_is_service_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if video gallery section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_video_gallery_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[video_gallery_section_enable]' )->value() );
}

/**
 * Check if video gallery section content type is post.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_video_gallery_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[video_gallery_content_type]' )->value();
	return travel_life_pro_is_video_gallery_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if video gallery section content type is page.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_video_gallery_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[video_gallery_content_type]' )->value();
	return travel_life_pro_is_video_gallery_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is post.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[blog_content_type]' )->value();
	return travel_life_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[blog_content_type]' )->value();
	return travel_life_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[blog_content_type]' )->value();
	return travel_life_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[blog_content_type]' )->value();
	return travel_life_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}

function travel_life_pro_is_blog_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[blog_content_type]' )->value();
	return travel_life_pro_is_blog_section_enable( $control ) && ( 'trip' == $content_type );
}

function travel_life_pro_is_blog_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[blog_content_type]' )->value();
	return travel_life_pro_is_blog_section_enable( $control ) && ( 'trip-types' == $content_type );
}

function travel_life_pro_is_blog_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[blog_content_type]' )->value();
	return travel_life_pro_is_blog_section_enable( $control ) && ( 'activity' == $content_type );
}

function travel_life_pro_is_blog_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[blog_content_type]' )->value();
	return travel_life_pro_is_blog_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if discover places section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_discover_places_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[discover_places_section_enable]' )->value() );
}

/**
 * Check if discover places section content type is page.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_discover_places_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[discover_places_content_type]' )->value();
	return travel_life_pro_is_discover_places_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if discover places section content type is post.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_discover_places_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[discover_places_content_type]' )->value();
	return travel_life_pro_is_discover_places_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if discover places section content type is trip.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_discover_places_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[discover_places_content_type]' )->value();
	return travel_life_pro_is_discover_places_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if discover places section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_discover_places_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[discover_places_content_type]' )->value();
	return travel_life_pro_is_discover_places_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if discover places section content type is trip types.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_discover_places_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[discover_places_content_type]' )->value();
	return travel_life_pro_is_discover_places_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if discover places section content type is destination.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_discover_places_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[discover_places_content_type]' )->value();
	return travel_life_pro_is_discover_places_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if discover places section content type is activity.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_discover_places_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[discover_places_content_type]' )->value();
	return travel_life_pro_is_discover_places_section_enable( $control ) && ( 'activity' == $content_type );
}

/**
 * Check if testimonial section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_testimonial_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[testimonial_section_enable]' )->value() );
}

/**
 * Check if testimonial section content type is post.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_testimonial_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[testimonial_content_type]' )->value();
	return travel_life_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if testimonial section content type is page.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_testimonial_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[testimonial_content_type]' )->value();
	return travel_life_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if testimonial section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_testimonial_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[testimonial_content_type]' )->value();
	return travel_life_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if testimonial section content type is custom.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_testimonial_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[testimonial_content_type]' )->value();
	return travel_life_pro_is_testimonial_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if testimonial section content type is author.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_testimonial_section_content_author_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[testimonial_content_type]' )->value();
	return travel_life_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if subscription section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_subscription_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[subscription_section_enable]' )->value() );
}

/**
 * Check if video section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_video_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[video_section_enable]' )->value() );
}

/**
 * Check if video section content type is post.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_video_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[video_content_type]' )->value();
	return travel_life_pro_is_video_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if video section content type is page.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_video_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[video_content_type]' )->value();
	return travel_life_pro_is_video_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if video section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_video_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[video_content_type]' )->value();
	return travel_life_pro_is_video_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if video section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_heading_tags_enable( $control ) {

	$tags = $control->manager->get_setting( 'travel_life_pro_theme_options[heading_tags]' )->value();
	return ($control->id == 'travel_life_pro_theme_options['.$tags.']');

}

/*Popular section*/

/**
 * Check if popular section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_popular_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[popular_section_enable]' )->value() );
}

/**
 * Check if popular section content type is post.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_popular_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[popular_content_type]' )->value();
	return travel_life_pro_is_popular_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular section content type is page.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_popular_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[popular_content_type]' )->value();
	return travel_life_pro_is_popular_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_popular_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[popular_content_type]' )->value();
	return travel_life_pro_is_popular_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular section content type is recent.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_popular_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[popular_content_type]' )->value();
	return travel_life_pro_is_popular_section_enable( $control ) && ( 'recent' == $content_type );
}

/*end Popular section*/


/*recent section*/

function travel_life_pro_is_recent_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[recent_section_enable]' )->value() );
}

function travel_life_pro_is_recent_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[recent_content_type]' )->value();
	return travel_life_pro_is_recent_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if recent section content type is page.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_recent_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[recent_content_type]' )->value();
	return travel_life_pro_is_recent_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if recent section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_recent_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[recent_content_type]' )->value();
	return travel_life_pro_is_recent_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if recent section content type is recent.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_recent_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[recent_content_type]' )->value();
	return travel_life_pro_is_recent_section_enable( $control ) && ( 'recent' == $content_type );
}

/*end recent section*/

/*most view section*/

function travel_life_pro_is_most_view_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[most_view_section_enable]' )->value() );
}

function travel_life_pro_is_most_view_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[most_view_content_type]' )->value();
	return travel_life_pro_is_most_view_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if most_view section content type is page.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_most_view_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[most_view_content_type]' )->value();
	return travel_life_pro_is_most_view_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if most_view section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_most_view_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[most_view_content_type]' )->value();
	return travel_life_pro_is_most_view_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if most_view section content type is most_view.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_most_view_section_content_most_view_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[most_view_content_type]' )->value();
	return travel_life_pro_is_most_view_section_enable( $control ) && ( 'recent' == $content_type );
}

/*Popular Product section*/

function travel_life_pro_is_popular_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[popular_product_section_enable]' )->value() );
}

function travel_life_pro_is_popular_product_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[popular_product_content_type]' )->value();
	return travel_life_pro_is_popular_product_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular_product section content type is product.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_popular_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[popular_product_content_type]' )->value();
	return travel_life_pro_is_popular_product_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if popular_product section content type is product_cat.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_popular_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[popular_product_content_type]' )->value();
	return travel_life_pro_is_popular_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

/**
 * Check if popular_product section content type is recent_product.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_popular_product_section_content_recent_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[recent_product_content_type]' )->value();
	return travel_life_pro_is_popular_product_section_enable( $control ) && ( 'recent_product' == $content_type );
}

/*Popular Product section*/

function travel_life_pro_is_latest_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[latest_product_section_enable]' )->value() );
}

function travel_life_pro_is_latest_product_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[latest_product_content_type]' )->value();
	return travel_life_pro_is_latest_product_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular_product section content type is product.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_latest_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[latest_product_content_type]' )->value();
	return travel_life_pro_is_latest_product_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if popular_product section content type is product_cat.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_latest_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[latest_product_content_type]' )->value();
	return travel_life_pro_is_latest_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

/**
 * Check if popular_product section content type is recent_product.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_latest_product_section_content_recent_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[recent_product_content_type]' )->value();
	return travel_life_pro_is_latest_product_section_enable( $control ) && ( 'recent_product' == $content_type );
}


/*end most view section*/

/**
 * Check if advertisement section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_advertisement_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[advertisement_section_enable]' )->value() );
}


/*most view section*/

function travel_life_pro_is_featured_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[featured_product_section_enable]' )->value() );
}

function travel_life_pro_is_featured_product_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[featured_product_content_type]' )->value();
	return travel_life_pro_is_featured_product_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if most_view section content type is page.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_featured_product_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[featured_product_content_type]' )->value();
	return travel_life_pro_is_featured_product_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if most_view section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */

function travel_life_pro_is_featured_product_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[featured_product_content_type]' )->value();
	return travel_life_pro_is_featured_product_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if most_view section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */

function travel_life_pro_is_featured_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[featured_product_content_type]' )->value();
	return travel_life_pro_is_featured_product_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if team section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_team_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[team_section_enable]' )->value() );
}

/**
 * Check if team section content type is post.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[team_content_type]' )->value();
	return travel_life_pro_is_team_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if team section seperator.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_team_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[team_content_type]' )->value();
	return travel_life_pro_is_team_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if team section content type is page.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[team_content_type]' )->value();
	return travel_life_pro_is_team_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if team section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[team_content_type]' )->value();
	return travel_life_pro_is_team_section_enable( $control ) && ( 'category' == $content_type );
}


/**
 * Check if cta section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_cta_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[cta_section_enable]' )->value() );
}

/**
 * Check if cta section content type is post.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_cta_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[cta_content_type]' )->value();
	return travel_life_pro_is_cta_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if cta section content type is page.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_cta_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[cta_content_type]' )->value();
	return travel_life_pro_is_cta_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if cta section content type is custom.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_cta_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[cta_content_type]' )->value();
	return travel_life_pro_is_cta_section_enable( $control ) && ( 'custom' == $content_type );
}

//--------------Counter section------------------------//

/**
 * Check if counter section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_counter_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[counter_section_enable]' )->value() );
}

//--------------Latest Post section------------------------//

/**
 * Check if latest_post section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_latest_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[latest_post_section_enable]' )->value() );
}

/**
 * Check if latest_post section content type is post.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_latest_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[latest_post_content_type]' )->value();
	return travel_life_pro_is_latest_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if latest_post section content type is page.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_latest_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[latest_post_content_type]' )->value();
	return travel_life_pro_is_latest_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if latest_post section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_latest_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[latest_post_content_type]' )->value();
	return travel_life_pro_is_latest_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if latest_post section content type is recent.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_latest_post_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[latest_post_content_type]' )->value();
	return travel_life_pro_is_latest_post_section_enable( $control ) && ( 'recent' == $content_type );
}

function travel_life_pro_is_latest_post_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[latest_post_content_type]' )->value();
	return travel_life_pro_is_latest_post_section_enable( $control ) && ( 'trip' == $content_type );
}

function travel_life_pro_is_latest_post_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[latest_post_content_type]' )->value();
	return travel_life_pro_is_latest_post_section_enable( $control ) && ( 'trip-types' == $content_type );
}

function travel_life_pro_is_latest_post_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[latest_post_content_type]' )->value();
	return travel_life_pro_is_latest_post_section_enable( $control ) && ( 'activity' == $content_type );
}

function travel_life_pro_is_latest_post_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[latest_post_content_type]' )->value();
	return travel_life_pro_is_latest_post_section_enable( $control ) && ( 'destination' == $content_type );
}


/**
 * Check if gallery section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_gallery_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[gallery_section_enable]' )->value() );
}
/**
 * Check if gallery section content type is post.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_gallery_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[gallery_content_type]' )->value();
	return travel_life_pro_is_gallery_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if gallery section seperator.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_gallery_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[gallery_content_type]' )->value();
	return travel_life_pro_is_gallery_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if gallery section content type is page.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_gallery_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[gallery_content_type]' )->value();
	return travel_life_pro_is_gallery_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if gallery section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_gallery_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[gallery_content_type]' )->value();
	return travel_life_pro_is_gallery_section_enable( $control ) && ( 'category' == $content_type );
}


/**
 * Check if product_collection section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_product_collection_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[product_collection_section_enable]' )->value() );
}

/**
 * Check if product_collection section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_product_collection_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[product_collection_content_type]' )->value();
	return travel_life_pro_is_product_collection_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if product_collection section content type is page.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_product_collection_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[product_collection_content_type]' )->value();
	return travel_life_pro_is_product_collection_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if product_collection section content type is post.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_product_collection_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[product_collection_content_type]' )->value();
	return travel_life_pro_is_product_collection_section_enable( $control ) && ( 'post' == $content_type );
}


/*Popular Product section*/

function travel_life_pro_is_recent_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[recent_product_section_enable]' )->value() );
}

function travel_life_pro_is_recent_product_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[recent_product_content_type]' )->value();
	return travel_life_pro_is_recent_product_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if recent_product section content type is product.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_recent_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[recent_product_content_type]' )->value();
	return travel_life_pro_is_recent_product_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if recent_product section content type is product_cat.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_recent_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[recent_product_content_type]' )->value();
	return travel_life_pro_is_recent_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

/**
 * Check if recent_product section content type is recent_product.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_recent_product_section_content_recent_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[recent_product_content_type]' )->value();
	return travel_life_pro_is_recent_product_section_enable( $control ) && ( 'recent_product' == $content_type );
}


/**
 * Check if Trending Product section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_trending_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[trending_product_section_enable]' )->value() );
}

/**
 * Check if trending_product section content type is post.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */

function travel_life_pro_is_trending_product_section_content_category_enable_1( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[trending_content_type_1]' )->value();
	return travel_life_pro_is_trending_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

function travel_life_pro_is_trending_product_section_content_category_enable_2( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[trending_content_type_2]' )->value();
	return travel_life_pro_is_trending_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

function travel_life_pro_is_trending_product_section_content_category_enable_3( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[trending_content_type_3]' )->value();
	return travel_life_pro_is_trending_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

function travel_life_pro_is_trending_product_section_content_product_enable_1( $control ) {
		$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[trending_content_type_1]' )->value();
	return travel_life_pro_is_trending_product_section_enable( $control ) && ( 'product' == $content_type );
}

function travel_life_pro_is_trending_product_section_content_product_enable_2( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[trending_content_type_2]' )->value();
	return travel_life_pro_is_trending_product_section_enable( $control ) && ( 'product' == $content_type );
}

function travel_life_pro_is_trending_product_section_content_product_enable_3( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[trending_content_type_3]' )->value();
	return travel_life_pro_is_trending_product_section_enable( $control ) && ( 'product' == $content_type );
}

//--------------Latest Post section------------------------//

/**
 * Check if featured_post section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_featured_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[featured_post_section_enable]' )->value() );
}

/**
 * Check if featured_post section content type is post.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_featured_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[featured_post_content_type]' )->value();
	return travel_life_pro_is_featured_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if featured_post section content type is page.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_featured_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[featured_post_content_type]' )->value();
	return travel_life_pro_is_featured_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured_post section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_featured_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[featured_post_content_type]' )->value();
	return travel_life_pro_is_featured_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if featured_post section content type is recent.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_featured_post_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[featured_post_content_type]' )->value();
	return travel_life_pro_is_featured_post_section_enable( $control ) && ( 'recent' == $content_type );
}

//--------------Latest Post section------------------------//

/**
 * Check if highlighted_news section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_highlighted_news_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[highlighted_news_section_enable]' )->value() );
}

/**
 * Check if highlighted_news section content type is post.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_highlighted_news_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[highlighted_news_content_type]' )->value();
	return travel_life_pro_is_highlighted_news_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if highlighted_news section content type is page.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_highlighted_news_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[highlighted_news_content_type]' )->value();
	return travel_life_pro_is_highlighted_news_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if highlighted_news section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_highlighted_news_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[highlighted_news_content_type]' )->value();
	return travel_life_pro_is_highlighted_news_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if highlighted_news section content type is recent.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_highlighted_news_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[highlighted_news_content_type]' )->value();
	return travel_life_pro_is_highlighted_news_section_enable( $control ) && ( 'recent' == $content_type );
}

//--------------Three Column News section------------------------//

/**
 * Check if three_column_news section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_three_column_news_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[three_column_news_section_enable]' )->value() );
}

/**
 * Check if three_column_news section content type is post.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_three_column_news_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[three_column_news_content_type]' )->value();
	return travel_life_pro_is_three_column_news_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if three_column_news section content type is page.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_three_column_news_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[three_column_news_content_type]' )->value();
	return travel_life_pro_is_three_column_news_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if three_column_news section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_three_column_news_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[three_column_news_content_type]' )->value();
	return travel_life_pro_is_three_column_news_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if three_column_news section content type is recent.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_three_column_news_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[three_column_news_content_type]' )->value();
	return travel_life_pro_is_three_column_news_section_enable( $control ) && ( 'recent' == $content_type );
}


//--------------Featured News section------------------------//

/**
 * Check if featured_news section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_featured_news_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[featured_news_section_enable]' )->value() );
}

/**
 * Check if featured_news section content type is post.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_featured_news_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[featured_news_content_type]' )->value();
	return travel_life_pro_is_featured_news_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if featured_news section content type is page.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_featured_news_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[featured_news_content_type]' )->value();
	return travel_life_pro_is_featured_news_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured_news section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_featured_news_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[featured_news_content_type]' )->value();
	return travel_life_pro_is_featured_news_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if featured_news section content type is recent.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_featured_news_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[featured_news_content_type]' )->value();
	return travel_life_pro_is_featured_news_section_enable( $control ) && ( 'recent' == $content_type );
}


//--------------Recent News section------------------------//

/**
 * Check if recent_news section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_recent_news_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[recent_news_section_enable]' )->value() );
}

/**
 * Check if recent_news section content type is post.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_recent_news_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[recent_news_content_type]' )->value();
	return travel_life_pro_is_recent_news_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if recent_news section content type is page.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_recent_news_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[recent_news_content_type]' )->value();
	return travel_life_pro_is_recent_news_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if recent_news section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_recent_news_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[recent_news_content_type]' )->value();
	return travel_life_pro_is_recent_news_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if recent_news section content type is recent.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_recent_news_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[recent_news_content_type]' )->value();
	return travel_life_pro_is_recent_news_section_enable( $control ) && ( 'recent' == $content_type );
}

//--------------Popular News section------------------------//

/**
 * Check if popular_news section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_popular_news_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[popular_news_section_enable]' )->value() );
}

/**
 * Check if popular_news section content type is post.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_popular_news_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[popular_news_content_type]' )->value();
	return travel_life_pro_is_popular_news_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular_news section content type is page.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_popular_news_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[popular_news_content_type]' )->value();
	return travel_life_pro_is_popular_news_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular_news section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_popular_news_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[popular_news_content_type]' )->value();
	return travel_life_pro_is_popular_news_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular_news section content type is recent.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_popular_news_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[popular_news_content_type]' )->value();
	return travel_life_pro_is_popular_news_section_enable( $control ) && ( 'recent' == $content_type );
}

//--------------Sport News section------------------------//

/**
 * Check if sport_news section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_sport_news_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[sport_news_section_enable]' )->value() );
}

/**
 * Check if sport_news section content type is post.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_sport_news_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[sport_news_content_type]' )->value();
	return travel_life_pro_is_sport_news_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if sport_news section content type is page.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_sport_news_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[sport_news_content_type]' )->value();
	return travel_life_pro_is_sport_news_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if sport_news section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_sport_news_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[sport_news_content_type]' )->value();
	return travel_life_pro_is_sport_news_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if sport_news section content type is recent.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_sport_news_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[sport_news_content_type]' )->value();
	return travel_life_pro_is_sport_news_section_enable( $control ) && ( 'recent' == $content_type );
}


//--------------Two Column News section------------------------//

/**
 * Check if two_column_news section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_two_column_news_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[two_column_news_section_enable]' )->value() );
}

/**
 * Check if two_column_news section content type is post.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_two_column_news_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[two_column_news_content_type]' )->value();
	return travel_life_pro_is_two_column_news_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if two_column_news section content type is page.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_two_column_news_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[two_column_news_content_type]' )->value();
	return travel_life_pro_is_two_column_news_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if two_column_news section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_two_column_news_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[two_column_news_content_type]' )->value();
	return travel_life_pro_is_two_column_news_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if two_column_news section content type is recent.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_two_column_news_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[two_column_news_content_type]' )->value();
	return travel_life_pro_is_two_column_news_section_enable( $control ) && ( 'recent' == $content_type );
}
//--------------Latest News section------------------------//

/**
 * Check if latest_news section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_latest_news_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_life_pro_theme_options[latest_news_section_enable]' )->value() );
}

/**
 * Check if latest_news section content type is post.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_latest_news_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[latest_news_content_type]' )->value();
	return travel_life_pro_is_latest_news_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if latest_news section content type is page.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_latest_news_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[latest_news_content_type]' )->value();
	return travel_life_pro_is_latest_news_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if latest_news section content type is category.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_latest_news_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[latest_news_content_type]' )->value();
	return travel_life_pro_is_latest_news_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if latest_news section content type is recent.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_latest_news_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[latest_news_content_type]' )->value();
	return travel_life_pro_is_latest_news_section_enable( $control ) && ( 'recent' == $content_type );
}

/**
 * Check if first  design section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_first_design_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[home_layout]' )->value();
	return ( 'default-design' == $content_type || 'pro-design' == $content_type);
}

/**
 * Check if fourth  design section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_fourth_design_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[home_layout]' )->value();
	return ( 'fourth-design' == $content_type || 'default-design' == $content_type);
}

/**
 * Check if sixth  design section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_sixth_design_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[home_layout]' )->value();
	return ( 'sixth-design' == $content_type || 'default-design' == $content_type );
}
/**
 * Check if seventh  design section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_seventh_design_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[home_layout]' )->value();
	return ( 'seventh-design' == $content_type || 'default-design' == $content_type );
}
/**
 * Check if slider  design section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_slider_design_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_life_pro_theme_options[home_layout]' )->value();
	return ( $content_type !== 'sixth-design' );
}

/**
 * Check if testimonial counter subscription design section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_first_second_third_fourth_fifth_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'travel_life_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout,array('default-design','second-design','third-design','fourth-design','fifth-design', 'pro-design'));
}
/**
 * Check if gallery design section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_gallery_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'travel_life_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout,array('default-design', 'second-design','third-design','fifth-design'));
}

/**
 * Check if latest_post design section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_latest_post_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'travel_life_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout,array('pro-design', 'default-design', 'second-design','third-design', 'fifth-design', 'seventh-design'));
}

/**
 * Check if First Second Third Fifth design section is enabled.
 *
 * @since Travel Life Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_life_pro_is_first_second_third_fifth_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'travel_life_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout,array('default-design','second-design','third-design','fifth-design', 'pro-design'));
}