<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Travel Life Pro
 * @since Travel Life Pro 1.0.0
 * @return array An array of default values
 */

function travel_life_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$travel_life_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#fff',
		'header_tagline_color'			=> '#fff',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#00afe9',
		'colorscheme'					=> 'default',
		'theme_version'					=> 'lite-version',
		'home_layout'					=> 'pro-design',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',

		//body typography
		'body_font_family'			=> 'Muli',
		'body_font_weight'			=> 300,
		'body_font_size'			=> 16,
		'body_font_style'			=> 'normal',
		'body_text_transform'		=> 'none',

		//h1 typography
		'heading_h1_font_family'		=> 'Raleway',
		'heading_h1_font_weight'		=> 300,
		'heading_h1_text_transform'		=> 'none',
		'heading_h1_font_style'			=> 'normal',

		//h2 typography
		'heading_h2_font_family'		=> 'Raleway',
		'heading_h2_font_weight'		=> 700,
		'heading_h2_text_transform'		=> 'none',
		'heading_h2_font_style'			=> 'normal',

		//h3 typography
		'heading_h3_font_family'		=> 'Raleway',
		'heading_h3_font_weight'		=> 700,
		'heading_h3_text_transform'		=> 'none',
		'heading_h3_font_style'			=> 'normal',

		//h4 typography
		'heading_h4_font_family'		=> 'Raleway',
		'heading_h4_font_weight'		=> 700,
		'heading_h4_text_transform'		=> 'none',
		'heading_h4_font_style'			=> 'normal',

		//h5 typography
		'heading_h5_font_family'		=> 'Raleway',
		'heading_h5_font_weight'		=> 700,
		'heading_h5_text_transform'		=> 'none',
		'heading_h5_font_style'			=> 'normal',

		//h6 typography
		'heading_h6_font_family'		=> 'Raleway',
		'heading_h6_font_weight'		=> 700,
		'heading_h6_text_transform'		=> 'none',
		'heading_h6_font_style'			=> 'normal',

		//p typography
		'heading_p_font_family'			=> 'Muli',
		'heading_p_font_weight'			=> 400,
		'heading_p_text_transform'		=> 'none',
		'heading_p_font_style'			=> 'normal',

		//button
		'button_background_color'		=> '#e5f8fc',
		'button_text_color'		=> '#00afe9',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide-layout',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'social_nav_enable'				=> true,


		// excerpt options
		'long_excerpt_length'           => 25,
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'travel-life-pro' ), '[the-year]', '[site-link]' ),
		'powered_by_text'           	=> esc_html__( 'All Rights Reserved | ', 'travel-life-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'travel-life-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'slider,trip_search,package,counter,about,latest_post,subscription,testimonial,popular_destination,gallery,latest_product,popular_product,product_collection,recent_product,featured_product,trending_product,highlighted_news,three_column_news,featured_news,recent_news,most_view,popular_news,sport_news,two_column_news,latest_news,blog,featured_post,recent',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'travel-life-pro' ),
		'hide_date' 					=> false,
		'hide_category'					=> false,
		'hide_author'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// topbar
		'top_bar_contact_enable'			=> true,
		'top_advertisement_enable'			=> true,
		'topbar_button_enable'			=> true,
		'topbar_btn_text'				=> esc_html__( 'Travel Enquiries', 'travel-life-pro' ),

		// Slider
		'slider_section_enable'			=> true,
		'slider_autoplay'				=> false,
		'slider_cloud'					=> true,
		'slider_content_type'			=> 'category',
		'slider_count'					=> 3,
		'slider_btn_label'				=> esc_html__( 'Discover More', 'travel-life-pro' ),
		'slider_video_label'			=> esc_html__( 'Watch the video', 'travel-life-pro' ),


		// trip search
		'trip_search_section_enable'	=> true,
		'trip_search_placeholder_1'		=> esc_html__( 'Ex: Trekking', 'travel-life-pro' ),
		'trip_search_placeholder_2'		=> esc_html__( 'Trip Type', 'travel-life-pro' ),
		'trip_search_placeholder_3'		=> esc_html__( 'Destination', 'travel-life-pro' ),

		// counter
		'counter_section_enable'			=> true,
		'counter_count'					=> 5,

		// featured
		'featured_title'				=> esc_html__( 'FEATURED POSTS', 'travel-life-pro' ),
		'featured_section_enable'		=> true,
		'featured_content_type'			=> 'category',
		'featured_count'				=> 4,
		'featured_read_more'			=> esc_html__( 'See Details', 'travel-life-pro' ),

		// popular destination
		'popular_destination_section_enable'	=> true,
		'popular_destination_content_type'		=> 'category',
		'popular_destination_count'				=> 4,
		'popular_destination_title'				=> esc_html__( 'Popular Trips', 'travel-life-pro' ),
		'popular_destination_subtitle'				=> esc_html__( 'Travelife is a leading training, management and certification initiative for tourism companies committed to reaching sustainability.', 'travel-life-pro' ),
		'popular_destination_read_more'			=> esc_html__( 'Book Now', 'travel-life-pro' ),
		'popular_destination_btn_title'			=> esc_html__( 'Show All', 'travel-life-pro' ),

		// about
		'about_section_enable'			=> true,
		'about_content_type'			=> 'page',
		'about_title'					=> esc_html__( 'Travel Life, let’s make your best trip ever!', 'travel-life-pro' ),
		'about_description'				=> esc_html__( 'Get official travel information about where to go and what to see to help you plan your next trip to Nepal.A trekkers paradise, Nepal combines Himalayan views, golden temples, charming hill villages and jungle wildlife watching to offer one of the worlds great travel destinations.', 'travel-life-pro' ),
		'about_btn_title'				=> esc_html__( 'Explore More', 'travel-life-pro' ),

		// Latest Post
		'latest_post_section_enable'			=> true,
		'latest_post_content_type'				=> 'recent',
		'latest_post_count'					=> 4,
		'latest_post_title'					=> esc_html__( 'Every Travel News', 'travel-life-pro' ),
		'latest_post_subtitle'					=> esc_html__( 'Travelife is a leading training, management and certification initiative for tourism companies committed to reaching sustainability.', 'travel-life-pro' ),
		'latest_post_btn_title'				=> esc_html__( 'Read More', 'travel-life-pro' ),

		// project
		'project_section_enable'			=> false,
		'project_content_type'			=> 'page',
		'project_title'					=> esc_html__( 'OUR PROJECTS', 'travel-life-pro' ),
		'project_btn_title'				=> esc_html__( 'View All Project', 'travel-life-pro' ),

		// package
		'package_section_enable'		=> true,
		'package_count'					=> 4,
		'package_content_type'			=> 'category',
		'package_title'					=> esc_html__( 'Recommended Packages', 'travel-life-pro' ),
		'package_sub_title'					=> esc_html__( 'Travelife is a leading training, management and certification initiative for tourism companies committed to reaching sustainability.', 'travel-life-pro' ),
		'package_btn_title'				=> esc_html__( 'Explore Now', 'travel-life-pro' ),

		// traveler_choice
		'traveler_choice_section_enable'	=> true,
		'traveler_choice_autoplay'			=> true,
		'traveler_choice_content_type'		=> 'category',
		'traveler_choice_count'				=> 3,
		'traveler_choice_read_more'			=> esc_html__( 'Book This Trip', 'travel-life-pro' ),

		// service
		'service_section_enable'		=> true,
		'service_section_icon_enable'	=> true,
		'service_content_type'			=> 'category',
		'service_count'					=> 3,

		// video
		'video_section_enable'			=> false,
		'video_content_type'			=> 'category',
		'video_count'					=> 5,
		'video_title'					=> esc_html__( 'Travel Videos', 'travel-life-pro' ),
		'video_btn_title'				=> esc_html__( 'View All Video', 'travel-life-pro' ),

		// video_gallery
		'video_gallery_section_enable'	=> true,
		'video_gallery_content_type'	=> 'post',
		'video_gallery_video_title'		=> esc_html__( 'Travel Videos', 'travel-life-pro' ),
		'video_gallery_sub_title'		=> esc_html__( 'Video of the day', 'travel-life-pro' ),
		'video_gallery_title'			=> esc_html__( 'The tallest living terrestrial animals and ruminants!', 'travel-life-pro' ),
		'video_gallery_post_title'		=> esc_html__( 'Gallery Posts', 'travel-life-pro' ),
		
		//services
		'service_title'					=> esc_html__( 'We Are In A Mission To Help The Helpless', 'travel-life-pro' ),

		// blog
		'blog_section_enable'			=> true,
		'blog_content_type'				=> 'recent',
		'blog_count'					=> 4,
		'blog_title'					=> esc_html__( 'Amazing travel Articles', 'travel-life-pro' ),
		'blog_subtitle'					=> esc_html__( 'Amazing travel Articles', 'travel-life-pro' ),
		'blog_readmore_text'				=> esc_html__( 'Read More', 'travel-life-pro' ),

		// discover places
		'discover_places_section_enable'	=> true,
		'discover_places_auto_play'			=> false,
		'discover_places_content_type'		=> 'category',
		'discover_places_count'				=> 3,
		'discover_places_sub_title'			=> esc_html__( 'Last Minute', 'travel-life-pro' ),
		'discover_places_read_more'			=> esc_html__( 'View Details', 'travel-life-pro' ),

		// testimonial
		'testimonial_section_enable'	=> true,
		'testimonial_auto_play'			=> false,
		'testimonial_content_type'		=> 'category',
		'testimonial_count'				=> 4,
		'testimonial_section_title'		=> esc_html__( 'What Our Clients Says', 'travel-life-pro' ),
		'testimonial_section_subtitle'		=> esc_html__( 'Travelife is a leading training, management and certification initiative for tourism companies committed to reaching sustainability.', 'travel-life-pro' ),
		'testimonial_section_btn_text'		=> esc_html__( 'Show All', 'travel-life-pro' ),

		// subscription
		'subscription_section_enable'	=> true,
		'subscription_sub_title'		=> esc_html__( 'Keep in touch', 'travel-life-pro' ),
		'subscription_title'			=> esc_html__( 'Travel with us!', 'travel-life-pro' ),
		'subscription_btn_title'		=> esc_html__( 'Subscribe Now', 'travel-life-pro' ),

		// popular
		'popular_section_enable'			=> true,
		'popular_content_type'				=> 'category',
		'popular_count'						=> 3,
		'popular_post_title'				=> esc_html__( 'Popular Post', 'travel-life-pro' ),
		'popular_post_readmore_text'		=> esc_html__( 'Continue Reading', 'travel-life-pro' ),

		// recent
		'recent_section_enable'			=> true,
		'recent_title'					=> esc_html__( 'RECENT POSTS', 'travel-life-pro' ),
		'recent_content_type'			=> 'category',
		'recent_count'					=> 4,

		// most_view
		'most_view_section_enable'			=> true,
		'most_view_content_type'			=> 'category',
		'most_view_count'					=> 2,
		'most_view_title'					=> esc_html__( 'MOST VIEWED POSTS', 'travel-life-pro' ),

		// popular product
		'popular_product_section_enable'	=> true,
		'popular_product_title'				=> esc_html__( 'Popular Products', 'travel-life-pro' ),
		'popular_product_sub_title'		=> esc_html__( 'Latest spring collection for fashionable person like you.', 'travel-life-pro' ),
		'popular_product_count'				=> 4,
		'popular_product_content_type'		=> 'product',

		// recent product
		'recent_product_section_enable'	=> true,
		'recent_product_title'				=> esc_html__( 'Recent Products', 'travel-life-pro' ),
		'recent_product_sub_title'		=> esc_html__( 'Latest spring collection for fashionable person like you.', 'travel-life-pro' ),
		'recent_product_count'				=> 4,
		'recent_product_content_type'		=> 'product',

		'product_collection_section_enable'		=> true,
		'product_collection_content_type'		=> 'post',
		'product_collection_title'				=> esc_html__( 'Spring Collection 2020', 'travel-life-pro' ),
		'product_collection_sub_title'			=> esc_html__( 'Latest spring collection for fashionable person like you.', 'travel-life-pro' ),
		'product_collection_count'				=> 4,

		//trending_product 
		'trending_product_section_enable'				=> true,
		'trending_product_count'						=> 4,
		'trending_product_section_buttom_slider_enable'	=> true,

		// latest Product
		'latest_product_section_enable'		=> true,
		'latest_product_title'				=> esc_html__( 'NEW ARRIVALS', 'travel-life-pro' ),
		'latest_product_description'		=> esc_html__( 'All Styles in This Spring', 'travel-life-pro' ),
		'latest_product_count'				=> 4,
		'latest_product_content_type'		=> 'product',

		// Featured Product
		'featured_product_section_enable'		=> true,
		'latest_product_title'				=> esc_html__( 'NEW ARRIVALS', 'travel-life-pro' ),
		'latest_product_description'		=> esc_html__( 'All Styles in This Spring', 'travel-life-pro' ),
		'latest_product_count'				=> 4,
		'featured_product_content_type'		=> 'category',

		// Team 
		'team_section_enable'		=> true,
		'team_title'				=> esc_html__( 'OUR EXPERT VOLUNTEER', 'travel-life-pro' ),
		'team_count'				=> 4,
		'team_content_type'			=> 'category',

		// CTA 
		'cta_section_enable'		=> true,
		'cta_title'				=> esc_html__( 'We need Volunteers around the World', 'travel-life-pro' ),
		'cta_btn_title'				=> esc_html__( 'Donate Now', 'travel-life-pro' ),
		'cta_content_type'			=> 'page',

		//gallery section
		'gallery_section_enable'			=> true,
		'gallery_subtitle'		=> esc_html__( 'Company that offers design and build services for you from initial sketches to the final production.', 'travel-life-pro' ),
		'gallery_title'			=> esc_html__( 'Our Gallery', 'travel-life-pro' ),
		'gallery_content_type'			=> 'post',
		'gallery_count'					=> 6,

		// Featured Post
		'featured_post_section_enable'			=> true,
		'featured_post_content_type'				=> 'recent',
		'featured_post_count'					=> 3,
		'featured_post_title'					=> esc_html__( 'Featured Posts', 'travel-life-pro' ),

		// highlighted_news
		'highlighted_news_section_enable'			=> true,
		'highlighted_news_content_type'			=> 'post',
		'highlighted_news_count'					=> 5,


		// Three Column Post
		'three_column_news_section_enable'			=> true,
		'three_column_news_content_type'				=> 'post',
		'three_column_news_count'					=> 3,
		'three_column_news_title'					=> esc_html__( 'Three Column Posts', 'travel-life-pro' ),

		// Featured Post
		'featured_news_section_enable'			=> true,
		'featured_news_content_type'				=> 'post',
		'featured_news_count'					=> 4,
		'featured_news_title'					=> esc_html__( 'Featured News', 'travel-life-pro' ),

		// recent Post
		'recent_news_section_enable'			=> true,
		'recent_news_content_type'				=> 'post',
		'recent_news_count'					=> 3,
		'recent_news_title'					=> esc_html__( 'Recent News', 'travel-life-pro' ),

		// popular Post
		'popular_news_section_enable'			=> true,
		'popular_news_content_type'				=> 'post',
		'popular_news_count'					=> 3,
		'popular_news_title'					=> esc_html__( 'Popular News', 'travel-life-pro' ),

		// sport Post
		'sport_news_section_enable'			=> true,
		'sport_news_content_type'				=> 'post',
		'sport_news_count'					=> 4,
		'sport_news_title'					=> esc_html__( 'Sport News', 'travel-life-pro' ),

		// two_column Post
		'two_column_news_section_enable'			=> true,
		'two_column_news_content_type'				=> 'post',
		'two_column_news_count'					=> 4,
		'two_column_news_title'					=> esc_html__( 'Two Column News', 'travel-life-pro' ),

		// latest Post
		'latest_news_section_enable'			=> true,
		'latest_news_content_type'				=> 'post',
		'latest_news_count'					=> 3,
		'latest_news_title'					=> esc_html__( 'Latest News', 'travel-life-pro' ),

		//advertisement
		'advertisement_section_enable'			=> true,
	);

	$output = apply_filters( 'travel_life_pro_default_theme_options', $travel_life_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}