<?php
/**
 * Featured Post Section options
 *
 * @package Theme Palace
 * @subpackage Travel Life Pro
 * @since Travel Life Pro 1.0.0
 */

// Add Featured Post section
$wp_customize->add_section( 'travel_life_pro_featured_post_section', array(
	'title'             => esc_html__( 'Featured Post','travel-life-pro' ),
	'description'       => esc_html__( 'Featured Post Section options.', 'travel-life-pro' ),
	'panel'             => 'travel_life_pro_front_page_panel',
	'active_callback'	=> 'travel_life_pro_is_seventh_design_enable',
) );

// Featured Post content enable control and setting
$wp_customize->add_setting( 'travel_life_pro_theme_options[featured_post_section_enable]', array(
	'default'			=> 	$options['featured_post_section_enable'],
	'sanitize_callback' => 'travel_life_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Life_Pro_Switch_Control( $wp_customize, 'travel_life_pro_theme_options[featured_post_section_enable]', array(
	'label'             => esc_html__( 'Featured Post Section Enable', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_featured_post_section',
	'on_off_label' 		=> travel_life_pro_switch_options(),
) ) );

// blog title setting and control
$wp_customize->add_setting( 'travel_life_pro_theme_options[featured_post_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['featured_post_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[featured_post_title]', array(
	'label'           	=> esc_html__( 'Title', 'travel-life-pro' ),
	'section'        	=> 'travel_life_pro_featured_post_section',
	'active_callback' 	=> 'travel_life_pro_is_featured_post_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_life_pro_theme_options[featured_post_title]', array(
		'selector'            => '#blog-featured-posts .section-header h2.section-title',
		'settings'            => 'travel_life_pro_theme_options[featured_post_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_life_pro_featured_post_title_partial',
    ) );
}

// Featured Post content type control and setting
$wp_customize->add_setting( 'travel_life_pro_theme_options[featured_post_content_type]', array(
	'default'          	=> $options['featured_post_content_type'],
	'sanitize_callback' => 'travel_life_pro_sanitize_select',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[featured_post_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_featured_post_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travel_life_pro_is_featured_post_section_enable',
	'choices'			=> travel_life_pro_latest_post_content_type(),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'travel_life_pro_theme_options[featured_post_count]', array(
	'default'          	=> $options['featured_post_count'],
	'sanitize_callback' => 'travel_life_pro_sanitize_number_range',
	'validate_callback' => 'travel_life_pro_validate_featured_post_count',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[featured_post_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'travel-life-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_featured_post_section',
	'active_callback'   => 'travel_life_pro_is_featured_post_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['featured_post_count']; $i++ ) :
	// blog pages drop down chooser control and setting
	$wp_customize->add_setting( 'travel_life_pro_theme_options[featured_post_content_page_' . $i . ']', array(
		'sanitize_callback' => 'travel_life_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Chooser( $wp_customize, 'travel_life_pro_theme_options[featured_post_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'travel-life-pro' ), $i ),
		'section'           => 'travel_life_pro_featured_post_section',
		'choices'			=> travel_life_pro_page_choices(),
		'active_callback'	=> 'travel_life_pro_is_featured_post_section_content_page_enable',
	) ) );

	// blog posts drop down chooser control and setting
	$wp_customize->add_setting( 'travel_life_pro_theme_options[featured_post_content_post_' . $i . ']', array(
		'sanitize_callback' => 'travel_life_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Chooser( $wp_customize, 'travel_life_pro_theme_options[featured_post_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'travel-life-pro' ), $i ),
		'section'           => 'travel_life_pro_featured_post_section',
		'choices'			=> travel_life_pro_post_choices(),
		'active_callback'	=> 'travel_life_pro_is_featured_post_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_life_pro_theme_options[featured_post_content_category]', array(
	'sanitize_callback' => 'travel_life_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Taxonomy_Control( $wp_customize,'travel_life_pro_theme_options[featured_post_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'travel-life-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_featured_post_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_life_pro_is_featured_post_section_content_category_enable'
) ) );

// Add dropdown categories setting and control.
$wp_customize->add_setting( 'travel_life_pro_theme_options[featured_post_category_exclude]', array(
	'sanitize_callback' => 'travel_life_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Category_Control( $wp_customize,'travel_life_pro_theme_options[featured_post_category_exclude]', array(
	'label'             => esc_html__( 'Select Excluding Categories', 'travel-life-pro' ),
	'description'      	=> esc_html__( 'Note: Select categories to exclude. Press Shift key select multilple categories.', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_featured_post_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'travel_life_pro_is_featured_post_section_content_recent_enable'
) ) );

