<?php
/**
 * popular_product Section options
 *
 * @package Theme Palace
 * @subpackage Travel Life Pro
 * @since Travel Life Pro 1.0.0
 */
if ( !class_exists('WooCommerce') ) {
    return;
}
// Add popular_product section
$wp_customize->add_section( 'travel_life_pro_latest_product_section', array(
    'title'             => esc_html__( 'Latest Product Section','travel-life-pro' ),
    'description'       => esc_html__( 'Latest Product Section Section options.', 'travel-life-pro' ),
    'panel'             => 'travel_life_pro_front_page_panel',
    'active_callback'   => 'travel_life_pro_is_fourth_design_enable',
) );

// popular_product content enable control and setting
$wp_customize->add_setting( 'travel_life_pro_theme_options[latest_product_section_enable]', array(
    'default'           =>  $options['latest_product_section_enable'],
    'sanitize_callback' => 'travel_life_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Life_Pro_Switch_Control( $wp_customize, 'travel_life_pro_theme_options[latest_product_section_enable]', array(
    'label'             => esc_html__( 'Popular product Section Enable', 'travel-life-pro' ),
    'section'           => 'travel_life_pro_latest_product_section',
    'on_off_label'      => travel_life_pro_switch_options(),
) ) );

$wp_customize->add_setting( 'travel_life_pro_theme_options[latest_product_count]', array(
    'default'           => $options['latest_product_count'],
    'sanitize_callback' => 'travel_life_pro_sanitize_number_range',
    'validate_callback' => 'travel_life_pro_validate_latest_product_count',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[latest_product_count]', array(
    'label'             => esc_html__( 'Number of Product', 'travel-life-pro' ),
    'description'       => esc_html__( 'Note: Min 4 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'travel-life-pro' ),
    'section'           => 'travel_life_pro_latest_product_section',
    'active_callback'   => 'travel_life_pro_is_latest_product_section_enable',
    'type'              => 'number',
    'input_attrs'       => array(
        'min'   => 4,
        'max'   => 12,
        'style' => 'width: 100px;'
        ),
) );

$wp_customize->add_setting( 'travel_life_pro_theme_options[latest_product_content_type]', array(
    'default'           => $options['latest_product_content_type'],
    'sanitize_callback' => 'travel_life_pro_sanitize_select',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[latest_product_content_type]', array(
    'label'             => esc_html__( 'Content Type', 'travel-life-pro' ),
    'section'           => 'travel_life_pro_latest_product_section',
    'type'              => 'select',
    'active_callback'   => 'travel_life_pro_is_latest_product_section_enable',
    'choices'           => travel_life_pro_latest_product_content_type(),
) );

for( $i = 1 ; $i <= $options['latest_product_count'] ; $i++ ){

    $wp_customize->add_setting( 'travel_life_pro_theme_options[latest_product_content_product_' . $i . ']', array(
        'sanitize_callback' => 'travel_life_pro_sanitize_page',
    ) );

    $wp_customize->add_control( new Travel_Life_Pro_Dropdown_Chooser( $wp_customize, 'travel_life_pro_theme_options[latest_product_content_product_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Product %d', 'travel-life-pro' ), $i ),
        'section'           => 'travel_life_pro_latest_product_section',
        'choices'           => travel_life_pro_product_choices(),
        'active_callback'   => 'travel_life_pro_is_latest_product_section_content_product_enable',
    ) ) );
}

$wp_customize->add_setting( 'travel_life_pro_theme_options[latest_product_content_product_category]', array(
        'sanitize_callback' => 'travel_life_pro_sanitize_select',
        'default'   => 1,
    ) );

    $wp_customize->add_control( new Travel_Life_Pro_Dropdown_Chooser( $wp_customize, 'travel_life_pro_theme_options[latest_product_content_product_category]', array(
        'label'             => esc_html__( 'Select Product Category', 'travel-life-pro' ),
        'section'           => 'travel_life_pro_latest_product_section',
        'choices'           => travel_life_pro_get_woo_product_cat(),
        'active_callback'   => 'travel_life_pro_is_latest_product_section_content_product_category_enable',
    ) ) );