<?php
/**
 * popular_product Section options
 *
 * @package Theme Palace
 * @subpackage Travel Life Pro
 * @since Travel Life Pro 1.0.0
 */
if ( !class_exists('WooCommerce') ) {
    return;
}

// Add popular_product section
$wp_customize->add_section( 'travel_life_pro_popular_product_section', array(
    'title'             => esc_html__( 'Popular Product','travel-life-pro' ),
    'description'       => esc_html__( 'Popular Product Section options.', 'travel-life-pro' ),
    'panel'             => 'travel_life_pro_front_page_panel',
    'active_callback'   => 'travel_life_pro_is_fourth_design_enable',
) );

// popular_product content enable control and setting
$wp_customize->add_setting( 'travel_life_pro_theme_options[popular_product_section_enable]', array(
    'default'           =>  $options['popular_product_section_enable'],
    'sanitize_callback' => 'travel_life_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Life_Pro_Switch_Control( $wp_customize, 'travel_life_pro_theme_options[popular_product_section_enable]', array(
    'label'             => esc_html__( 'Popular product Section Enable', 'travel-life-pro' ),
    'section'           => 'travel_life_pro_popular_product_section',
    'on_off_label'      => travel_life_pro_switch_options(),
) ) );




// popular_product title setting and control
$wp_customize->add_setting( 'travel_life_pro_theme_options[popular_product_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['popular_product_title'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[popular_product_title]', array(
    'label'             => esc_html__( 'Title', 'travel-life-pro' ),
    'section'           => 'travel_life_pro_popular_product_section',
    'active_callback'   => 'travel_life_pro_is_popular_product_section_enable',
    'type'              => 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_life_pro_theme_options[popular_product_title]', array(
        'selector'            => '#popular-products .section-header h2',
        'settings'            => 'travel_life_pro_theme_options[popular_product_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'travel_life_pro_popular_product_title_partial',
    ) ); 
}

// popular_product title setting and control
$wp_customize->add_setting( 'travel_life_pro_theme_options[popular_product_sub_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['popular_product_sub_title'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[popular_product_sub_title]', array(
    'label'             => esc_html__( 'Sub Title', 'travel-life-pro' ),
    'section'           => 'travel_life_pro_popular_product_section',
    'active_callback'   => 'travel_life_pro_is_popular_product_section_enable',
    'type'              => 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_life_pro_theme_options[popular_product_sub_title]', array(
        'selector'            => '#popular-products .section-header p',
        'settings'            => 'travel_life_pro_theme_options[popular_product_sub_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'travel_life_pro_popular_product_sub_title_partial',
    ) );
}

$wp_customize->add_setting( 'travel_life_pro_theme_options[popular_product_count]', array(
    'default'           => $options['popular_product_count'],
    'sanitize_callback' => 'travel_life_pro_sanitize_number_range',
    'validate_callback' => 'travel_life_pro_validate_popular_product_count',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[popular_product_count]', array(
    'label'             => esc_html__( 'Number of Product', 'travel-life-pro' ),
    'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'travel-life-pro' ),
    'section'           => 'travel_life_pro_popular_product_section',
    'active_callback'   => 'travel_life_pro_is_popular_product_section_enable',
    'type'              => 'number',
    'input_attrs'       => array(
        'min'   => 1,
        'max'   => 12,
        'style' => 'width: 100px;'
        ),
) );

$wp_customize->add_setting( 'travel_life_pro_theme_options[popular_product_content_type]', array(
    'default'           => $options['popular_product_content_type'],
    'sanitize_callback' => 'travel_life_pro_sanitize_select',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[popular_product_content_type]', array(
    'label'             => esc_html__( 'Content Type', 'travel-life-pro' ),
    'section'           => 'travel_life_pro_popular_product_section',
    'type'              => 'select',
    'active_callback'   => 'travel_life_pro_is_popular_product_section_enable',
    'choices'           => travel_life_pro_popular_product_options(),
) );

for( $i = 1 ; $i <= $options['popular_product_count'] ; $i++ ){

    $wp_customize->add_setting( 'travel_life_pro_theme_options[popular_product_content_page_' . $i . ']', array(
        'sanitize_callback' => 'travel_life_pro_sanitize_page',
    ) );

    $wp_customize->add_control( new Travel_Life_Pro_Dropdown_Chooser( $wp_customize, 'travel_life_pro_theme_options[popular_product_content_page_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Product %d', 'travel-life-pro' ), $i ),
        'section'           => 'travel_life_pro_popular_product_section',
        'choices'           => travel_life_pro_product_choices(),
        'active_callback'   => 'travel_life_pro_is_popular_product_section_content_product_enable',
    ) ) );
}

$wp_customize->add_setting( 'travel_life_pro_theme_options[popular_product_category]', array(
    'sanitize_callback' => 'travel_life_pro_sanitize_select',
    'default'   => 1,
) );

$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Chooser( $wp_customize, 'travel_life_pro_theme_options[popular_product_category]', array(
    'label'             => esc_html__( 'Select Product Category', 'travel-life-pro' ),
    'section'           => 'travel_life_pro_popular_product_section',
    'choices'           => travel_life_pro_get_woo_product_cat(),
    'active_callback'   => 'travel_life_pro_is_popular_product_section_content_product_category_enable',
) ) );