<?php
/**
 * Slider Section options
 *
 * @package Theme Palace
 * @subpackage Travel Life Pro
 * @since Travel Life Pro 1.0.0
 */

// Add Slider section
$wp_customize->add_section( 'travel_life_pro_slider_section', array(
	'title'             => esc_html__( 'Main Slider','travel-life-pro' ),
	'description'       => esc_html__( 'Slider Section options.', 'travel-life-pro' ),
	'panel'             => 'travel_life_pro_front_page_panel',
	'active_callback'	=> 'travel_life_pro_is_slider_design_enable',
) );

// Slider content enable control and setting
$wp_customize->add_setting( 'travel_life_pro_theme_options[slider_section_enable]', array(
	'default'			=> 	$options['slider_section_enable'],
	'sanitize_callback' => 'travel_life_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Life_Pro_Switch_Control( $wp_customize, 'travel_life_pro_theme_options[slider_section_enable]', array(
	'label'             => esc_html__( 'Slider Section Enable', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_slider_section',
	'on_off_label' 		=> travel_life_pro_switch_options(),
) ) );

// Slider content enable control and setting
$wp_customize->add_setting( 'travel_life_pro_theme_options[slider_autoplay]', array(
	'default'			=> 	$options['slider_autoplay'],
	'sanitize_callback' => 'travel_life_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Life_Pro_Switch_Control( $wp_customize, 'travel_life_pro_theme_options[slider_autoplay]', array(
	'label'             => esc_html__( 'Auto Play Enable', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_slider_section',
	'on_off_label' 		=> travel_life_pro_switch_options(),
	'active_callback' 	=> 'travel_life_pro_is_slider_section_enable',
) ) );

$wp_customize->add_setting( 'travel_life_pro_theme_options[slider_cloud]', array(
	'default'			=> 	$options['slider_cloud'],
	'sanitize_callback' => 'travel_life_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Life_Pro_Switch_Control( $wp_customize, 'travel_life_pro_theme_options[slider_cloud]', array(
	'label'             => esc_html__( 'Enable Cloud', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_slider_section',
	'on_off_label' 		=> travel_life_pro_switch_options(),
	'active_callback' 	=> 'travel_life_pro_is_slider_section_enable',
) ) );

// Slider btn label setting and control
$wp_customize->add_setting( 'travel_life_pro_theme_options[slider_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['slider_btn_label'],
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[slider_btn_label]', array(
	'label'           	=> esc_html__( 'Slider Button Label', 'travel-life-pro' ),
	'section'        	=> 'travel_life_pro_slider_section',
	'active_callback' 	=> 'travel_life_pro_is_slider_section_enable',
	'type'				=> 'text',
) );


// Event social icons number control and setting
$wp_customize->add_setting( 'travel_life_pro_theme_options[slider_count]', array(
	'default'          	=> $options['slider_count'],
	'sanitize_callback' => 'travel_life_pro_sanitize_number_range',
	'validate_callback' => 'travel_life_pro_validate_slider_count',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[slider_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'travel-life-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_slider_section',
	'active_callback'   => 'travel_life_pro_is_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// Slider content type control and setting
$wp_customize->add_setting( 'travel_life_pro_theme_options[slider_content_type]', array(
	'default'          	=> $options['slider_content_type'],
	'sanitize_callback' => 'travel_life_pro_sanitize_select',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[slider_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travel_life_pro_is_slider_section_enable',
	'choices'			=> travel_life_pro_main_slider_content_type(),
) );

for ( $i = 1; $i <= $options['slider_count']; $i++ ) :
	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'travel_life_pro_theme_options[slider_content_page_' . $i . ']', array(
		'sanitize_callback' => 'travel_life_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Chooser( $wp_customize, 'travel_life_pro_theme_options[slider_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'travel-life-pro' ), $i ),
		'section'           => 'travel_life_pro_slider_section',
		'choices'			=> travel_life_pro_page_choices(),
		'active_callback'	=> 'travel_life_pro_is_slider_section_content_page_enable',
	) ) );

	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'travel_life_pro_theme_options[slider_content_post_' . $i . ']', array(
		'sanitize_callback' => 'travel_life_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Chooser( $wp_customize, 'travel_life_pro_theme_options[slider_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'travel-life-pro' ), $i ),
		'section'           => 'travel_life_pro_slider_section',
		'choices'			=> travel_life_pro_post_choices(),
		'active_callback'	=> 'travel_life_pro_is_slider_section_content_post_enable',
	) ) );

	$wp_customize->add_setting( 'travel_life_pro_theme_options[slider_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'travel_life_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Chooser( $wp_customize, 'travel_life_pro_theme_options[slider_content_trip_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Trip %d', 'travel-life-pro' ), $i ),
		'section'           => 'travel_life_pro_slider_section',
		'choices'			=> travel_life_pro_trip_choices(),
		'active_callback'	=> 'travel_life_pro_is_slider_section_content_trip_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_life_pro_theme_options[slider_content_category]', array(
	'sanitize_callback' => 'travel_life_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Taxonomy_Control( $wp_customize,'travel_life_pro_theme_options[slider_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'travel-life-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_slider_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_life_pro_is_slider_section_content_category_enable'
) ) );


// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_life_pro_theme_options[slider_content_trip_types]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Taxonomy_Control( $wp_customize,'travel_life_pro_theme_options[slider_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_slider_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_life_pro_is_slider_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_life_pro_theme_options[slider_content_activity]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Taxonomy_Control( $wp_customize,'travel_life_pro_theme_options[slider_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_slider_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_life_pro_is_slider_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_life_pro_theme_options[slider_content_destination]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Taxonomy_Control( $wp_customize,'travel_life_pro_theme_options[slider_content_destination]', array(
	'label'             => esc_html__( 'Select Destinations', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_slider_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_life_pro_is_slider_section_content_destination_enable'
) ) );

