<?php
/**
 * Testimonial Section options
 *
 * @package Theme Palace
 * @subpackage Travel Life Pro
 * @since Travel Life Pro 1.0.0
 */

// Add Testimonial section
$wp_customize->add_section( 'travel_life_pro_testimonial_section', array(
	'title'             => esc_html__( 'Testimonial','travel-life-pro' ),
	'description'       => esc_html__( 'Testimonial Section options.', 'travel-life-pro' ),
	'panel'             => 'travel_life_pro_front_page_panel',
	'active_callback'	=> 'travel_life_pro_is_first_second_third_fourth_fifth_design_enable',
) );

// Testimonial content enable control and setting
$wp_customize->add_setting( 'travel_life_pro_theme_options[testimonial_section_enable]', array(
	'default'			=> 	$options['testimonial_section_enable'],
	'sanitize_callback' => 'travel_life_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Life_Pro_Switch_Control( $wp_customize, 'travel_life_pro_theme_options[testimonial_section_enable]', array(
	'label'             => esc_html__( 'Testimonial Section Enable', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_testimonial_section',
	'on_off_label' 		=> travel_life_pro_switch_options(),
) ) );

// Testimonial auto play enable control and setting
$wp_customize->add_setting( 'travel_life_pro_theme_options[testimonial_auto_play]', array(
	'default'			=> 	$options['testimonial_auto_play'],
	'sanitize_callback' => 'travel_life_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Life_Pro_Switch_Control( $wp_customize, 'travel_life_pro_theme_options[testimonial_auto_play]', array(
	'label'             => esc_html__( 'Auto Play Enable', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_testimonial_section',
	'on_off_label' 		=> travel_life_pro_switch_options(),
) ) );

$wp_customize->add_setting( 'travel_life_pro_theme_options[testimonial_section_title]', array(
	'default'          	=> $options['testimonial_section_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[testimonial_section_title]', array(
	'label'             => esc_html__( 'Section Title', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_testimonial_section',
	'type'				=> 'text',
	'active_callback' 	=> 'travel_life_pro_is_testimonial_section_enable',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_life_pro_theme_options[testimonial_section_title]', array(
		'selector'            => '#testimonial-section .wrapper .section-header h2.section-title',
		'settings'            => 'travel_life_pro_theme_options[testimonial_section_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_life_pro_testimonial_section_title_partial',
    ) );
}

$wp_customize->add_setting( 'travel_life_pro_theme_options[testimonial_section_subtitle]', array(
	'default'          	=> $options['testimonial_section_subtitle'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[testimonial_section_subtitle]', array(
	'label'             => esc_html__( 'Section Title', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_testimonial_section',
	'type'				=> 'text',
	'active_callback' 	=> 'travel_life_pro_is_testimonial_section_enable',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_life_pro_theme_options[testimonial_section_subtitle]', array(
		'selector'            => '#testimonial-section .section-header p.section-subtitle',
		'settings'            => 'travel_life_pro_theme_options[testimonial_section_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_life_pro_testimonial_section_subtitle_partial',
    ) );
}

$wp_customize->add_setting( 'travel_life_pro_theme_options[testimonial_section_btn_text]', array(
	'default'          	=> $options['testimonial_section_btn_text'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[testimonial_section_btn_text]', array(
	'label'             => esc_html__( 'Button text', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_testimonial_section',
	'type'				=> 'text',
	'active_callback' 	=> 'travel_life_pro_is_testimonial_section_enable',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_life_pro_theme_options[testimonial_section_btn_text]', array(
		'selector'            => '#testimonial-section .read-more a',
		'settings'            => 'travel_life_pro_theme_options[testimonial_section_btn_text]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_life_pro_testimonial_section_btn_text_partial',
    ) );
}


// testimonial btn link setting and control
$wp_customize->add_setting( 'travel_life_pro_theme_options[testimonial_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[testimonial_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'travel-life-pro' ),
	'section'        	=> 'travel_life_pro_testimonial_section',
	'active_callback' 	=> 'travel_life_pro_is_testimonial_section_enable',
	'type'				=> 'url',
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'travel_life_pro_theme_options[testimonial_count]', array(
	'default'          	=> $options['testimonial_count'],
	'sanitize_callback' => 'travel_life_pro_sanitize_number_range',
	'validate_callback' => 'travel_life_pro_validate_testimonial_count',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[testimonial_count]', array(
	'label'             => esc_html__( 'Number of Testimonials', 'travel-life-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_testimonial_section',
	'active_callback'   => 'travel_life_pro_is_testimonial_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// Testimonial content type control and setting
$wp_customize->add_setting( 'travel_life_pro_theme_options[testimonial_content_type]', array(
	'default'          	=> $options['testimonial_content_type'],
	'sanitize_callback' => 'travel_life_pro_sanitize_select',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[testimonial_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_testimonial_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travel_life_pro_is_testimonial_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'travel-life-pro' ),
		'post' 		=> esc_html__( 'Post', 'travel-life-pro' ),
		'category' 	=> esc_html__( 'Category', 'travel-life-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'travel-life-pro' ),
	),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_life_pro_theme_options[testimonial_content_category]', array(
	'sanitize_callback' => 'travel_life_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_life_pro_theme_options[testimonial_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'travel-life-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_testimonial_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_life_pro_is_testimonial_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['testimonial_count']; $i++ ) :
	// testimonial pages drop down chooser control and setting
	$wp_customize->add_setting( 'travel_life_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'sanitize_callback' => 'travel_life_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Chooser( $wp_customize, 'travel_life_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'travel-life-pro' ), $i ),
		'section'           => 'travel_life_pro_testimonial_section',
		'choices'			=> travel_life_pro_page_choices(),
		'active_callback'	=> 'travel_life_pro_is_testimonial_section_content_page_enable',
	) ) );

	// testimonial posts drop down chooser control and setting
	$wp_customize->add_setting( 'travel_life_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'sanitize_callback' => 'travel_life_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Chooser( $wp_customize, 'travel_life_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'travel-life-pro' ), $i ),
		'section'           => 'travel_life_pro_testimonial_section',
		'choices'			=> travel_life_pro_post_choices(),
		'active_callback'	=> 'travel_life_pro_is_testimonial_section_content_post_enable',
	) ) );

	// testimonial title setting and control
	$wp_customize->add_setting( 'travel_life_pro_theme_options[testimonial_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'travel_life_pro_theme_options[testimonial_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Title %d', 'travel-life-pro' ), $i ),
		'section'        	=> 'travel_life_pro_testimonial_section',
		'active_callback' 	=> 'travel_life_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'text',
	) );

	// testimonial position setting and control
	$wp_customize->add_setting( 'travel_life_pro_theme_options[testimonial_author_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'travel_life_pro_theme_options[testimonial_author_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Author %d', 'travel-life-pro' ), $i ),
		'section'        	=> 'travel_life_pro_testimonial_section',
		'active_callback' 	=> 'travel_life_pro_is_testimonial_section_content_author_enable',
		'type'				=> 'text',
	) );

	// testimonial description setting and control
	$wp_customize->add_setting( 'travel_life_pro_theme_options[testimonial_description_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( 'travel_life_pro_theme_options[testimonial_description_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Description %d', 'travel-life-pro' ), $i ),
		'section'        	=> 'travel_life_pro_testimonial_section',
		'active_callback' 	=> 'travel_life_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'textarea',
	) );

	// testimonial image setting and control.
	$wp_customize->add_setting( 'travel_life_pro_theme_options[testimonial_image_' . $i . ']', array(
		'sanitize_callback' => 'travel_life_pro_sanitize_image'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'travel_life_pro_theme_options[testimonial_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Image %d', 'travel-life-pro' ), $i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'travel-life-pro' ), 700, 600 ),
			'section'     		=> 'travel_life_pro_testimonial_section',
			'active_callback'	=> 'travel_life_pro_is_testimonial_section_content_custom_enable',
	) ) );

	// testimonial position setting and control
	$wp_customize->add_setting( 'travel_life_pro_theme_options[testimonial_link_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'travel_life_pro_theme_options[testimonial_link_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'URL Link %d', 'travel-life-pro' ), $i ),
		'section'        	=> 'travel_life_pro_testimonial_section',
		'active_callback' 	=> 'travel_life_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'url',
	) );

	// testimonial hr setting and control
	$wp_customize->add_setting( 'travel_life_pro_theme_options[testimonial_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Travel_Life_Pro_Customize_Horizontal_Line( $wp_customize, 'travel_life_pro_theme_options[testimonial_hr_'. $i .']',
		array(
			'section'         => 'travel_life_pro_testimonial_section',
			'active_callback' => 'travel_life_pro_is_testimonial_section_content_author_enable',
			'type'			  => 'hr'
	) ) );
endfor;

