<?php
/**
 * trending_product Section options
 *
 * @package Theme Palace
 * @subpackage Travel Life Pro
 * @since Travel Life Pro 1.0.0
 */
if ( !class_exists('WooCommerce') ) {
	return;
}
// Add trending_product section
$wp_customize->add_section( 'travel_life_pro_trending_product_section', array(
	'title'             => esc_html__( 'Trending Product','travel-life-pro' ),
	'description'       => esc_html__( 'Trending Product Section options.', 'travel-life-pro' ),
	'panel'             => 'travel_life_pro_front_page_panel',
	'active_callback'   => 'travel_life_pro_is_fourth_design_enable',
) );

// trending_product content enable control and setting
$wp_customize->add_setting( 'travel_life_pro_theme_options[trending_product_section_enable]', array(
	'default'			=> 	$options['trending_product_section_enable'],
	'sanitize_callback' => 'travel_life_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Life_Pro_Switch_Control( $wp_customize, 'travel_life_pro_theme_options[trending_product_section_enable]', array(
	'label'             => esc_html__( 'Trending Product Section Enable', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_trending_product_section',
	'on_off_label' 		=> travel_life_pro_switch_options(),
) ) );

$wp_customize->add_setting( 'travel_life_pro_theme_options[trending_product_count]', array(
	'default'          	=> $options['trending_product_count'],
	'sanitize_callback' => 'travel_life_pro_sanitize_number_range',
	'validate_callback' => 'travel_life_pro_validate_trending_product_count',
) );

$wp_customize->add_control( 'travel_life_pro_theme_options[trending_product_count]', array(
	'label'             => esc_html__( 'Number of Product Per Column', 'travel-life-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'travel-life-pro' ),
	'section'           => 'travel_life_pro_trending_product_section',
	'active_callback'   => 'travel_life_pro_is_trending_product_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for( $i = 1 ; $i <= 3 ; $i++ ){

	$wp_customize->add_setting( 'travel_life_pro_theme_options[trending_product_column_'. $i .']', array(
			'sanitize_callback' => 'sanitize_text_field'
		) );

	$wp_customize->add_control( new Travel_Life_Pro_Customize_Column( $wp_customize, 'travel_life_pro_theme_options[trending_product_column_'. $i .']',
		array(
			'label'			  => esc_html__('Column ', 'travel-life-pro').$i,
			'section'         => 'travel_life_pro_trending_product_section',
			'active_callback' => 'travel_life_pro_is_trending_product_section_enable',
			'type'			  => 'column'
	) ) );

	// trending_product title setting and control
	$wp_customize->add_setting( 'travel_life_pro_theme_options[trending_product_title_'.$i.']', array(
	    'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'travel_life_pro_theme_options[trending_product_title_'.$i.']', array(
	    'label'             => esc_html__( 'Title', 'travel-life-pro' ),
	    'section'           => 'travel_life_pro_trending_product_section',
	    'active_callback'   => 'travel_life_pro_is_trending_product_section_enable',
	    'type'              => 'text',
	) );

	$wp_customize->add_setting( 'travel_life_pro_theme_options[trending_content_type_'.$i.']', array(
		'default'          	=> 'product',
		'sanitize_callback' => 'travel_life_pro_sanitize_select',
	) );

	$wp_customize->add_control( 'travel_life_pro_theme_options[trending_content_type_'.$i.']', array(
		'label'             => esc_html__( 'Content Type', 'travel-life-pro' ),
		'section'           => 'travel_life_pro_trending_product_section',
		'type'				=> 'select',
		'active_callback' 	=> 'travel_life_pro_is_trending_product_section_enable',
		'choices'			=> travel_life_pro_popular_product_options(),
	) );

	for ( $j=1 ; $j <= $options['trending_product_count'] ; $j++ ) { 
		$wp_customize->add_setting( 'travel_life_pro_theme_options[trending_product_content_page_'. $i.$j. ']', array(
			'sanitize_callback' => 'travel_life_pro_sanitize_page',
		) );

		$wp_customize->add_control( new Travel_Life_Pro_Dropdown_Chooser( $wp_customize, 'travel_life_pro_theme_options[trending_product_content_page_' .$i.$j. ']', array(
				'label'             => sprintf( esc_html__( 'Select Product %d', 'travel-life-pro' ), $j ),
				'section'           => 'travel_life_pro_trending_product_section',
				'choices'			=> travel_life_pro_product_choices(),
				'active_callback'	=> 'travel_life_pro_is_trending_product_section_content_product_enable_'.$i,

		) ) );
	}

	$wp_customize->add_setting( 'travel_life_pro_theme_options[trending_product_category_' . $i . ']', array(
        'sanitize_callback' => 'travel_life_pro_sanitize_select',
        'default'   => 1,
    ) );

    $wp_customize->add_control( new Travel_Life_Pro_Dropdown_Chooser( $wp_customize, 'travel_life_pro_theme_options[trending_product_category_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Product Category %d', 'travel-life-pro' ), $i ),
        'section'           => 'travel_life_pro_trending_product_section',
        'choices'           => travel_life_pro_get_woo_product_cat(),
        'active_callback'   => 'travel_life_pro_is_trending_product_section_content_category_enable_'.$i,
    ) ) );

	$wp_customize->add_setting( 'travel_life_pro_theme_options[trending_product_hr_'. $i .']', array(
			'sanitize_callback' => 'sanitize_text_field'
		) );

	$wp_customize->add_control( new Travel_Life_Pro_Customize_Horizontal_Line( $wp_customize, 'travel_life_pro_theme_options[trending_product_hr_'. $i .']',
		array(
			'section'         => 'travel_life_pro_trending_product_section',
			'active_callback' => 'travel_life_pro_is_trending_product_section_enable',
			'type'			  => 'hr'
	) ) );

}
