<?php
/**
 * Blog section
 *
 * This is the template for the content of blog section
 *
 * @package Theme Palace
 * @subpackage Travel Life Pro
 * @since Travel Life Pro 1.0.0
 */
if ( ! function_exists( 'travel_life_pro_add_blog_section' ) ) :
    /**
    * Add blog section
    *
    *@since Travel Life Pro 1.0.0
    */
    function travel_life_pro_add_blog_section() {
    	$options = travel_life_pro_get_theme_options();
        // Check if blog is enabled on frontpage
        $blog_enable = apply_filters( 'travel_life_pro_section_status', true, 'blog_section_enable' );

        if ( true !== $blog_enable ) {
            return false;
        }
        // Get blog section details
        $section_details = array();
        $section_details = apply_filters( 'travel_life_pro_filter_blog_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render blog section now.
        travel_life_pro_render_blog_section( $section_details );
    }
endif;

if ( ! function_exists( 'travel_life_pro_get_blog_section_details' ) ) :
    /**
    * blog section details.
    *
    * @since Travel Life Pro 1.0.0
    * @param array $input blog section details.
    */
    function travel_life_pro_get_blog_section_details( $input ) {
        $options = travel_life_pro_get_theme_options();

        // Content type.
        $blog_content_type  = $options['blog_content_type'];
        $blog_count = ! empty( $options['blog_count'] ) ? $options['blog_count'] : 4;
        
        $content = array();
        switch ( $blog_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $blog_count; $i++ ) {
                    if ( ! empty( $options['blog_content_page_' . $i] ) )
                        $page_ids[] = $options['blog_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $blog_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $blog_count; $i++ ) {
                    if ( ! empty( $options['blog_content_post_' . $i] ) )
                        $post_ids[] = $options['blog_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $blog_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['blog_content_category'] ) ? $options['blog_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $blog_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['blog_category_exclude'] ) ? $options['blog_category_exclude'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $blog_count ),
                    'category__not_in'  => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = travel_life_pro_trim_content( 20 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg'; 

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// blog section content details.
add_filter( 'travel_life_pro_filter_blog_section_details', 'travel_life_pro_get_blog_section_details' );


if ( ! function_exists( 'travel_life_pro_render_blog_section' ) ) :
  /**
   * Start blog section
   *
   * @return string blog content
   * @since Travel Life Pro 1.0.0
   *
   */
   function travel_life_pro_render_blog_section( $content_details = array() ) {
        $options = travel_life_pro_get_theme_options();
        $blog_content_type  = $options['blog_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="blog-posts" class="relative page-section">
            <div class="wrapper">
                <?php if ( is_customize_preview()): ?>
                    <?php travel_life_pro_section_tooltip( 'blog-posts' ); ?>
                <?php endif ?>
                <div class="section-header">
                    <?php if ( ! empty( $options['blog_title'] ) ) : ?>
                        <h2 class="section-title"><?php echo esc_html( $options['blog_title'] ); ?></h2>
                    <?php endif; ?>
                    <?php if ( ! empty( $options['blog_subtitle'] ) ) : ?>
                        <p class="section-subtitle"><?php echo esc_html( $options['blog_subtitle'] ); ?></p>
                    <?php endif; ?>
                </div><!-- .section-header -->

                <div class="section-content archive-blog-wrapper col-3 clear">
                    <?php foreach ( $content_details as $content ) : ?>
                        <article class="has-post-thumbnail">
                            <div class="featured-image" style="background-image: url('<?php echo esc_url($content['image']) ?>');">
                                <a href="<?php echo esc_url($content['url']) ?>" class="post-thumbnail-link"></a>
                            </div><!-- .featured-image -->

                            <div class="entry-container">
                                <div class="entry-meta">
                                    <span class="cat-links">
                                        <?php if ($blog_content_type !='page'): ?>
                                            <span class="cat-links">
                                                <?php the_category('','', $content['id']); ?>
                                            </span><!-- .cat-links -->
                                        <?php endif; ?>                                                    
                                    </span><!-- .cat-links -->

                                    <?php travel_life_pro_posted_on( $content['id'] ); ?>
                                </div><!-- .entry-meta -->

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url($content['url']) ?>"><?php echo esc_html($content['title']) ?></a></h2>
                                </header>

                                <div class="entry-content">
                                    <p><?php echo esc_html($content['excerpt']) ?></p>
                                </div><!-- .entry-content -->
                                <?php if (!empty($options['blog_readmore_text'])): ?>
                                <div class="more-link">
                                    <a href="<?php echo esc_url($content['url']) ?>"><?php echo esc_html( $options['blog_readmore_text'] ) ?>
                                        <svg viewBox="0 0 292.359 292.359">
                                            <path d="M222.979,133.331L95.073,5.424C91.456,1.807,87.178,0,82.226,0c-4.952,0-9.233,1.807-12.85,5.424
                                            c-3.617,3.617-5.424,7.898-5.424,12.847v255.813c0,4.948,1.807,9.232,5.424,12.847c3.621,3.617,7.902,5.428,12.85,5.428
                                            c4.949,0,9.23-1.811,12.847-5.428l127.906-127.907c3.614-3.613,5.428-7.897,5.428-12.847
                                            C228.407,141.229,226.594,136.948,222.979,133.331z"/>
                                        </svg>
                                    </a>
                                </div><!-- .more-link -->
                            <?php endif; ?>
                            </div><!-- .entry-container -->
                        </article>
                    <?php endforeach; ?>
                </div><!-- .archive-blog-wrapper -->
            </div><!-- .wrapper -->
        </div><!-- #latest-posts -->
    <?php }
endif;