<?php
/**
 * Package section
 *
 * This is the template for the content of package section
 *
 * @package Theme Palace
 * @subpackage Travel Life Pro
 * @since Travel Life Pro 1.0.0
 */
if ( ! function_exists( 'travel_life_pro_add_package_section' ) ) :
    /**
    * Add package section
    *
    *@since Travel Life Pro 1.0.0
    */
    function travel_life_pro_add_package_section() {
    	$options = travel_life_pro_get_theme_options();
        // Check if destination is enabled on frontpage
        $package_enable = apply_filters( 'travel_life_pro_section_status', true, 'package_section_enable' );

        if ( true !== $package_enable ) {
            return false;
        }
        // Get destination section details
        $section_details = array();
        $section_details = apply_filters( 'travel_life_pro_filter_package_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render destination section now.
        travel_life_pro_render_package_section( $section_details );
    }
endif;

if ( ! function_exists( 'travel_life_pro_get_package_section_details' ) ) :
    /**
    * package section details.
    *
    * @since Travel Life Pro 1.0.0
    * @param array $input package section details.
    */
    function travel_life_pro_get_package_section_details( $input ) {
        $options = travel_life_pro_get_theme_options();

        // Content type.
        $package_content_type  = $options['package_content_type'];
        $package_count = ! empty( $options['package_count'] ) ? $options['package_count'] : 4;
        
        $content = array();
        if ($options['home_layout'] == 'pro-design') {
            switch ( $package_content_type ) {
                case 'category':
                    $cat = array();
                    for ( $i = 1; $i <= $package_count; $i++ ) {
                        if ( ! empty( $options['package_cat_' . $i] ) ){
                            $cat_id = $options['package_cat_' . $i];
                            $term = get_term( $cat_id, 'category' );
                            if(!is_wp_error( $term ) && $term){
                                $cat['count'] = $term->count;
                                $cat['name'] = $term->name;
                                $cat['des'] = $term->description;
                                $cat['url'] = get_term_link( $cat_id, 'category' );
                            
                                if ( ! empty( $cat ) ) {
                                    // Push to the main array.
                                    array_push( $content, $cat );
                                }
                            }
                        }
                    }
                break;

                case 'destination':
                if ( ! class_exists( 'WP_Travel' ) )
                        return;
                    $dest = array();
                    for ( $i = 1; $i <= $package_count; $i++ ) {
                        if ( ! empty( $options['package_destinations_' . $i] ) ){
                            $dest_id = $options['package_destinations_' . $i];
                            $term = get_term( $dest_id, 'travel_locations' );
                            if(!is_wp_error( $term ) && $term){
                                $dest['count'] = $term->count;
                                $dest['name'] = $term->name;
                                $dest['des'] = $term->description;
                                $dest['url'] = get_term_link( $dest_id, 'travel_locations' );
        
                                if ( ! empty( $dest ) ) {
                                    array_push( $content, $dest );
                                }
                            }
                        }
                    }                   
                break; 

                case 'trip-types':
                if ( ! class_exists( 'WP_Travel' ) )
                        return;
                    $trip_type = array();
                    for ( $i = 1; $i <= $package_count; $i++ ) {
                        if ( ! empty( $options['package_trip_' . $i] ) ){
                            $trip_id = $options['package_trip_' . $i];
                            $term = get_term( $trip_id, 'itinerary_types' );
                            if(!is_wp_error( $term ) && $term){
                                $trip_type['count'] = $term->count;
                                $trip_type['name'] = $term->name;
                                $trip_type['des'] = $term->description;
                                $trip_type['url'] = get_term_link( $trip_id, 'itinerary_types' );
                                
                                if ( ! empty( $trip_type ) ) {
                                    array_push( $content, $trip_type );
                                }
                            }
                          
                        }
                    }  
                break;

                default:
                break;
            }
        }
        if ($options['home_layout'] != 'pro-design') {
            switch ( $package_content_type ) {

                case 'category':
                    $cat_id = ! empty( $options['package_content_category'] ) ? $options['package_content_category'] : '';
                    $args = array(
                        'post_type'         => 'post',
                        'posts_per_page'    => absint( $package_count ),
                        'cat'               => absint( $cat_id ),
                        'ignore_sticky_posts'   => true,
                        );                    
                break;

                case 'page':
                    $page_ids = array();

                    for ( $i = 1; $i <= $package_count; $i++ ) {
                        if ( ! empty( $options['package_content_page_' . $i] ) )
                            $page_ids[] = $options['package_content_page_' . $i];
                    }
                    
                    $args = array(
                        'post_type'         => 'page',
                        'post__in'          => ( array ) $page_ids,
                        'posts_per_page'    => absint( $package_count ),
                        'orderby'           => 'post__in',
                        );                    
                break;

                case 'post':
                    $post_ids = array();

                    for ( $i = 1; $i <= $package_count; $i++ ) {
                        if ( ! empty( $options['package_content_post_' . $i] ) )
                            $post_ids[] = $options['package_content_post_' . $i];
                    }
                    
                    $args = array(
                        'post_type'         => 'post',
                        'post__in'          => ( array ) $post_ids,
                        'posts_per_page'    => absint( $package_count ),
                        'orderby'           => 'post__in',
                        'ignore_sticky_posts'   => true,
                        );                    
                break;

                default:
                break;
            }
        }
        if ($options['home_layout'] != 'pro-design') {

         // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = travel_life_pro_trim_content( 20 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        }
          
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// destination section content details.
add_filter( 'travel_life_pro_filter_package_section_details', 'travel_life_pro_get_package_section_details' );


if ( ! function_exists( 'travel_life_pro_render_package_section' ) ) :
  /**
   * Start destination section
   *
   * @return string destination content
   * @since Travel Life Pro 1.0.0
   *
   */
   function travel_life_pro_render_package_section( $content_details = array() ) {
        $options = travel_life_pro_get_theme_options();
        $package_content_type  = $options['package_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?> 

        <div id="top-destinations" class="relative page-section same-background">
                <div class="wrapper">
                    <div class="section-header-wrapper clear">
                        <?php if ( ! empty( $options['package_title'] ) ) : ?>
                            <div class="section-header">
                                <h2 class="section-title"><?php echo esc_html( $options['package_title'] ); ?></h2>
                                <?php if (!empty($options['package_sub_title'])): ?>
                                    <p class="section-subtitle"><?php echo esc_html( $options['package_sub_title'] ) ; ?></p>
                                <?php endif ?>
                            </div><!-- .section-header -->
                        <?php endif; ?>
                        <div class="destination-slider" data-slick='{"slidesToShow": 2, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":true, "autoplay": false, "draggable": true, "fade": false }'>
                            <?php $i=1; foreach ( $content_details as $content ) :  ?>
                                <?php if ($options['home_layout'] == 'pro-design'): ?>
                                    <article class="has-post-thumbnail">
                                        <?php if (!empty($options['package_image_' . $i])): ?>
                                            <div class="featured-image" style="background-image: url('<?php echo esc_url( ($options['package_image_' . $i])) ?>');">
                                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                            </div><!-- .featured-image -->
                                        <?php endif ?>
                                        <div class="entry-container">
                                            <header class="entry-header">
                                                <?php if ( ! empty( $content['count'] ) ) { ?>
                                                    <span class="trip-number"><?php echo absint( $content['count'] ) . esc_html__( ' Trips', 'travel-life-pro' ); ?></span>
                                                <?php } ?>
                                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"> 
                                                    <?php if ( ! empty( $content['name'] ) ) { ?>
                                                    <a href="<?php echo esc_url( $content['url'] ); ?>">
                                                        <?php echo esc_html( $content['name'] ); ?>
                                                    </a>
                                                <?php } ?></a></h2>
                                            </header>
                                            <?php if ( ! empty( $content['des'] ) ) { ?>
                                                <div class="entry-content">
                                                    <p><?php echo esc_html( $content['des'] ); ?></p>
                                                </div><!-- .entry-content -->
                                            <?php } ?>
                                           <?php if ( ! empty( $options['package_btn_title'] ) ) : ?>
                                                <div class="read-more">
                                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $options['package_btn_title'] ); ?></a>
                                                </div><!-- .read-more -->
                                            <?php endif; ?>
                                        </div><!-- .entry-container -->
                                    </article>
                                <?php endif; ?>
                                <?php if ($options['home_layout'] != 'pro-design'): ?>
                                    <article class="<?php echo ! empty( $content['image'] ) ? 'has' : 'no'; ?>-post-thumbnail">
                                        <div class="featured-image" style="background-image: url('<?php echo esc_url($content['image']) ?>');">
                                            <a href="<?php echo esc_url($content['url']) ?>" class="post-thumbnail-link"></a>
                                        </div><!-- .featured-image -->

                                        <div class="entry-container">
                                            <ul class="social-icons">
                                                <?php 
                                                $package_socials = ! empty( $options['package_social_' . $i ] ) ? explode( '|', $options['package_social_' . $i ] ) : array(); 

                                                foreach ( $package_socials as $package_social ) : ?>
                                                    <li>
                                                        <a href="<?php echo esc_url( $package_social ); ?>"><?php echo travel_life_pro_return_social_icon( $package_social ); ?></a>
                                                    </li>
                                                <?php endforeach; ?>
                                            </ul>
                                            <header class="entry-header">
                                                <h2 class="entry-title"><a href="<?php echo esc_url($content['url']) ?>"><?php echo esc_html($content['title']) ?></a></h2>
                                            </header>

                                            <div class="entry-content">
                                                <p><?php echo esc_html($content['excerpt']) ?></p>
                                            </div><!-- .entry-content -->

                                            <?php if ( ! empty( $options['package_btn_title'] ) ) : ?>
                                                <div class="read-more">
                                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $options['package_btn_title'] ); ?></a>
                                                </div><!-- .read-more -->
                                            <?php endif; ?>
                                        </div><!-- .entry-container -->
                                    </article>
                                <?php endif; ?>

                            <?php $i++; endforeach; ?>
                        </div><!-- .section-content -->
                        <div class="slick-controls"><span></span></div>
                    </div><!-- .section-header-wrapper -->
                    
                </div><!-- .wrapper -->
            </div><!-- #recommended-hotels -->
        
    <?php }
endif;